@@ -93,7 +93,11 @@ def two_dists(
         n_text = "n = " + str(n)
 
         bbox_props = dict(
-            boxstyle="round,pad=1", fc="lightgrey", ec="lightgrey", lw=0, alpha=0.33,
+            boxstyle="round,pad=1",
+            fc="lightgrey",
+            ec="lightgrey",
+            lw=0,
+            alpha=0.33,
         )
 
         ax.text(
@@ -113,13 +117,23 @@ def two_dists(
     if summary_type == "box":
 
         sns.boxplot(
-            binary, continuous, notch=True, palette=pal, ax=ax, **seaborn_kwargs,
+            binary,
+            continuous,
+            notch=True,
+            palette=pal,
+            ax=ax,
+            **seaborn_kwargs,
         )
 
     elif summary_type == "violin":
 
         sns.violinplot(
-            binary, continuous, inner=None, palette=pal, ax=ax, **seaborn_kwargs,
+            binary,
+            continuous,
+            inner=None,
+            palette=pal,
+            ax=ax,
+            **seaborn_kwargs,
         )
 
     else:
@@ -365,7 +379,11 @@ def roc_auc_curve(y, y_pred, ax=None):
 
     # summary box properties
     bbox_props = dict(
-        boxstyle="round,pad=0.5", fc="lightgrey", ec="lightgrey", lw=0, alpha=0.33,
+        boxstyle="round,pad=0.5",
+        fc="lightgrey",
+        ec="lightgrey",
+        lw=0,
+        alpha=0.33,
     )
 
     # add summary text
@@ -435,7 +453,11 @@ def pr_curve(y, y_pred, ax=None):
     ax.set_xlabel("Recall")
 
     bbox_props = dict(
-        boxstyle="round,pad=0.5", fc="lightgrey", ec="lightgrey", lw=0, alpha=0.33,
+        boxstyle="round,pad=0.5",
+        fc="lightgrey",
+        ec="lightgrey",
+        lw=0,
+        alpha=0.33,
     )
 
     ax.text(
